@@ -22,6 +22,8 @@
 #          pc3_v2: add ec[16],g,confidenceLevel
 #          this version lib same as pc3OVH 
 #
+# v2.0.1: 2022/06/10
+#
 
 import serial
 import time
@@ -348,16 +350,17 @@ class Pc3_v2:
 						ran = r * self.u.rangeUnit
 						snr = s * self.u.snrUnit
 						#print("({:2d}:{:4d})(idx:({:4d}) elv:{:.4f} azimuth:{:.4f} doppler:{:.4f} range:{:.4f} snr:{:.4f}".format(numOfPoints,lenCount,idx,elv,azi,dop,ran,snr))
+						sz  = ran * np.sin(elv)
+						sx  = ran * np.cos(elv) * np.sin(azi)
+						sy  = ran * np.cos(elv) * np.cos(azi)
 						
 						if (df == 'DataFrame'):
-							sz  = ran * np.sin(elv)
-							sx  = ran * np.cos(elv) * np.sin(azi)
-							sy  = ran * np.cos(elv) * np.cos(azi)
 							#v6df.append((self.hdr.frameNumber,'v6',elv,azi,dop,ran,snr,sx,sy,sz)) #v0.1.0
 							v6df.append((self.hdr.frameNumber,'v6',elv,azi,ran,dop,snr,sx,sy,sz)) #v0.1.1
 							 
 						else:
-							v6.append((elv,azi,dop,ran,snr))
+							#v6.append((elv,azi,dop,ran,snr)) 
+							v6.append((elv,azi,dop,ran,snr,sx,sy,sz)) #v2.0.1
 						
 						#print("point_cloud_2d.append:[{:d}]".format(len(point_cloud_2d)))
 						sbuf = b""
